@@ -8,9 +8,9 @@ import click
 import yaml
 from junitparser import TestCase, TestSuite, JUnitXml, Skipped, Error
 
-from rptf import api
-from rptf import schema
-from rptf import term
+import api
+import schema
+import term
 
 pipeline_running_states = ['running', 'waiting_for_resource', 'pending']
 
@@ -79,7 +79,7 @@ def execute_test(name, trigger, assertions):
 @click.option('--junit/--no-junit',
               default=True,
               help='Generate JUnit test report',)
-def test(target, junit):
+def main(target, junit):
     term.empty_line()
     term.header('Remote Pipeline Test Framework')
     validate_env_vars()
@@ -237,4 +237,4 @@ def test(target, junit):
 
 
 if __name__ == '__main__':
-    test()
+    main()
